scilpy.stats package
======================

scilpy.stats.matrix\_stats module
------------------------------------------------------

.. automodule:: scilpy.stats.matrix_stats
   :members:
   :undoc-members:
   :show-inheritance:

scilpy.stats.stats module
------------------------------------------------------

.. automodule:: scilpy.stats.stats
   :members:
   :undoc-members:
   :show-inheritance:

scilpy.stats.utils module
------------------------------------------------------

.. automodule:: scilpy.stats.utils
   :members:
   :undoc-members:
   :show-inheritance:
